ReifiedValue

Enum ReifiedValue 

pub enum ReifiedValue<'h> {
    Number(f64),
    Bool(bool),
    Null,
    List(&'h Vec<Value>, ListPointer),
    String(&'h str, StringPointer),
    Record(&'h IndexMap<String, Value>, RecordPointer),
    Lambda(&'h LambdaDef, LambdaPointer),
    Spread(ReifiedIterableValue<'h>, IterablePointer),
    BuiltIn(BuiltInFunction),
}
A value, after it has been “reified” (borrowed) from a pointer.

Variants



Number(f64)

A number is a floating-point value.



Bool(bool)

A boolean value is either true or false.



Null

A null value represents the absence of a value.



List(&'h Vec<Value>, ListPointer)

A list is a sequence of values.



String(&'h str, StringPointer)

A string is a sequence of characters.



Record(&'h IndexMap<String, Value>, RecordPointer)

A record is a collection of key-value pairs.



Lambda(&'h LambdaDef, LambdaPointer)

A lambda is a function definition.



Spread(ReifiedIterableValue<'h>, IterablePointer)

A spread value is “spread” into its container when it is used in a list, record, or function call. (internal only)



BuiltIn(BuiltInFunction)

A built-in function is a function that is implemented in Rust.

Implementations

Source

impl<'h> ReifiedValue<'h>

pub fn with_heap( &'h self, heap: Rc<RefCell<Heap>>, ) -> WithHeap<'h, ReifiedValue<'h>>